@@ -349,4 +349,90 @@ deviance_tests <- function(){
 }
 
 
+################################
+# Extended summary from multinom
+summaryMultinom <- function(object){
+	M <- summary(object, Wald=TRUE)
+	cat('Call:\n')
+	print(M$call)
+	if(terms(object)[[3]]!=1){
+		A <- Anova(object)}
+	N <- dim(M$Wald.ratios)
+	n <- prod(N)
+	lH <- numeric(n)
+	zeros <- rep(0,n)
+	if(!is.null(N) && n>1){
+		for(i in 1:n){
+			z.tmp <- zeros
+			z.tmp[i] <- 1
+			lH[i] <- linearHypothesis(object, z.tmp, rhs=0)[2,3]
+		}
+		p.values <- matrix(lH,N[1],N[2],byrow=TRUE)
+		result <- cbind(as.vector(t(M$coefficients)),as.vector(t(M$standard.errors)),as.vector(t(M$Wald.ratios)),as.vector(t(p.values)))
+		colnames(result) <- c('Coef','SE Coef','Z','P')
+	} else {
+		result <- cbind(as.vector(t(M$coefficients)),as.vector(t(M$standard.errors)),as.vector(t(M$Wald.ratios)))
+		colnames(result) <- c('Coef','SE Coef','Z')
+	}
+	rn <- rownames(M$coefficients)
+	cn <- colnames(M$coefficients)
+	j <- 0
+	if(!is.null(N) && n>1){
+		for(i in 1:N[1]){
+			R <- result[1:N[2]+j,,drop=FALSE]
+			dimnames(R) <- eval(parse(text=paste("list('", rn[i], "'=c('", paste(cn,collapse="','",sep=""), "'),", "c('Coef','SE Coef','Z','P'))", sep="")))
+			j <- j+N[2]
+			print(R)
+		}
+	}
+	cat("\n")
+	if(terms(object)[[3]]!=1){
+		print(A)}
+	cat(paste("\nResidual Deviance: ", round(M$deviance,4), "\n", sep=""))
+	cat(paste("AIC: ", round(M$AIC,4), "\n", sep=""))
+	print(logLik(object))
+}
+
+################################
+# Extended summary from multinom
+extend.colnames <- function(object, the.name){
+	if(is.matrix(object)){
+		colnames(object) <- paste(the.name,colnames(object),sep='.')
+	}
+	object
+}
+
+
+################################
+# Extended summary polr
+summaryOrdinal <- function(object, digits = max(3, .Options$digits - 3),
+                         correlation = FALSE, ...)
+{
+	if(terms(object)[[3]]!=1){
+		A <- Anova(object)}
+	lL <- logLik(object)
+    cc <- c(coef(object), object$zeta)
+    pc <- length(coef(object))
+    q <- length(object$zeta)
+    coef <- matrix(0, pc+q, 4L, dimnames=list(names(cc),
+                               c("  Coef", " SE Coef", "  Z", "  P")))
+    coef[, 1L] <- cc
+    vc <- vcov(object)
+    coef[, 2L] <- sd <- sqrt(diag(vc))
+    coef[, 3L] <- coef[, 1L]/coef[, 2L]
+	coef[, 4L] <- 1-pchisq(coef[, 3L]^2,1)
+    object$coefficients <- coef
+    object$pc <- pc
+    object$digits <- digits
+    if(correlation)
+        object$correlation <- (vc/sd)/rep(sd, rep(pc+q, pc+q))
+    class(object) <- "summary.polr"
+    print(object)
+	print(lL)
+	cat("\n")
+	if(terms(object)[[3]]!=1){
+		print(A)}
+}
+
+
 
